@@ -67,12 +67,12 @@ class QamasuJob(object):
     self.manager = manager
     self.org_job = job_data
     self.completed = False
-    logger.debug('Job id:%d initialize complete.' % (self.id,))
+    logger.debug('Job id:{0} initialize complete.'.format(self.id,))
   
   def complete(self):
     self.manager.dequeue(self)
     self.completed = True
-    logger.debug('Job id:%d completed.' % (self.id,))
+    logger.debug('Job id:{0} completed.'.format(self.id,))
   
   @property
   def is_completed(self):
@@ -80,7 +80,7 @@ class QamasuJob(object):
 
   def reenqueue(self, args):
     self.manager.reenqueue(self, args);
-    logger.debug('Job id:%d retry(enqueued).' % (self.id,))
+    logger.debug('Job id:{0} retry(enqueued).'.format(self.id,))
 
 
 class Manager(object):
@@ -139,7 +139,7 @@ class Manager(object):
     res = None
     try:
       res = worker_module.work_safely(self, job)
-    except Exception, e:
+    except Exception as e:
       self.job_failed(job.org_job, e)
     return res
   
@@ -171,10 +171,10 @@ class Manager(object):
                             grabbed_until=server_time + timedelta(seconds=worker_mod.GRAB_FOR)
                           )
       if not grabbed:
-        logger.debug("job(%d) is not found. Could be grabbed another worker.", job_data.id)
+        logger.debug("job({0}) is not found. Could be grabbed another worker.".format(job_data.id))
         continue
       grab_job = Job.objects.get(pk=job_data.id, uniqkey=new_uniqkey)
-      logger.debug('NEW:%s' % grab_job.grabbed_until)
+      logger.debug('NEW:{0}'.format(grab_job.grabbed_until))
       job = QamasuJob(manager=self, job_data=job_data)
       return job
     return None
